bayespy.inference.vmp.nodes.poisson.PoissonDistribution.random
==============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.random